@@ -81,10 +81,11 @@ class Style:
     """
     Documentation
     """
-    def __init__(self, row, column, data_type, font, alignment, fill, border):
+    def __init__(self, name, row, column, data_type, font, alignment, fill, border):
         """
         Documentation
         """
+        self.__name = name
         self.__row = row
         self.__column = column
         self.__data_type = data_type
@@ -93,6 +94,21 @@ class Style:
         self.__fill = copy(fill)
         self.__border = copy(border)
 
+    @property
+    def name(self):
+        """
+        Documentation
+        """
+        return self.__name
+
+    @name.setter
+    def name(self, name):
+        """
+        Documentation
+        """
+        self.__name = name
+        return None
+
     @property
     def row(self):
         """
@@ -186,6 +202,7 @@ class Model:
         self.__styles = []
         for row in self.__worksheet.iter_rows(min_row=1, max_col=self.__columns, max_row=self.__rows):
             for cell in row:
+                s = cell.coordinate
                 if cell.value != None:
                     value = str(cell.value)
                     if value[0]=='$':
@@ -210,7 +227,7 @@ class Model:
                 s = cell.coordinate
                 number = int(s[1:len(s)])
                 value = self.__worksheet.row_dimensions[number].height
-                self.__rows_height.append(Variable(str(number), cell.row, cell.column, value))
+                self.__rows_height.append(Variable(number, cell.row, cell.column, value))
 
     @property
     def rows(self):
@@ -271,12 +288,34 @@ class Model:
                 constantvalues.append(variable.value)
         return constantvalues
 
+    @property
+    def variable(self, name):
+        """
+        Documentation
+        """
+        result = 'Variable "'+name+'" not found.'
+        for variable in self.__variables:
+            if variable.name == name:
+                result = variable
+                break
+        return variable
+
     @property
     def mergedcells(self):
         """
         Documentation
         """
-        return self.__worksheet.merged_cells.ranges
+        ranges = []
+        for range in self.__worksheet.merged_cells.ranges:
+            ranges.append(str(range))
+        return ranges
+
+    @property
+    def variables(self):
+        """
+        Documentation
+        """
+        return self.__variables
 
     @property
     def styles(self):
